@@ -1,8 +1,27 @@
+/*
+Copyright The Kubernetes NMState Authors.
+
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+*/
+
 package helper
 
 import (
+	"bytes"
 	"context"
 	"fmt"
+	"os/exec"
 	"time"
 
 	"github.com/pkg/errors"
@@ -12,9 +31,9 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/client"
 	logf "sigs.k8s.io/controller-runtime/pkg/log"
 
+	"github.com/nmstate/kubernetes-nmstate/api/names"
 	"github.com/nmstate/kubernetes-nmstate/api/shared"
 	nmstatev1beta1 "github.com/nmstate/kubernetes-nmstate/api/v1beta1"
-	"github.com/nmstate/kubernetes-nmstate/pkg/names"
 	"github.com/nmstate/kubernetes-nmstate/pkg/nmstatectl"
 	"github.com/nmstate/kubernetes-nmstate/pkg/probe"
 )
@@ -32,6 +51,12 @@ const (
 	DesiredStateConfigurationTimeout = (defaultGwProbeTimeout + apiServerProbeTimeout) * 2
 )
 
+type DependencyVersions struct {
+	HandlerNetworkManagerVersion string
+	HandlerNmstateVersion        string
+	HostNmstateVersion           string
+}
+
 func InitializeNodeNetworkState(client client.Client, node *corev1.Node) (*nmstatev1beta1.NodeNetworkState, error) {
 	ownerRefList := []metav1.OwnerReference{{Name: node.ObjectMeta.Name, Kind: "Node", APIVersion: "v1", UID: node.UID}}
 
@@ -52,7 +77,7 @@ func InitializeNodeNetworkState(client client.Client, node *corev1.Node) (*nmsta
 	return &nodeNetworkState, nil
 }
 
-func CreateOrUpdateNodeNetworkState(client client.Client, node *corev1.Node, observedState shared.State, nns *nmstatev1beta1.NodeNetworkState) error {
+func CreateOrUpdateNodeNetworkState(client client.Client, node *corev1.Node, observedState shared.State, nns *nmstatev1beta1.NodeNetworkState, versions *DependencyVersions) error {
 	if nns == nil {
 		var err error
 		nns, err = InitializeNodeNetworkState(client, node)
@@ -60,16 +85,19 @@ func CreateOrUpdateNodeNetworkState(client client.Client, node *corev1.Node, obs
 			return err
 		}
 	}
-	return UpdateCurrentState(client, nns, observedState)
+	return UpdateCurrentState(client, nns, observedState, versions)
 }
 
-func UpdateCurrentState(client client.Client, nodeNetworkState *nmstatev1beta1.NodeNetworkState, observedState shared.State) error {
-
+func UpdateCurrentState(client client.Client, nodeNetworkState *nmstatev1beta1.NodeNetworkState, observedState shared.State, versions *DependencyVersions) error {
 	if observedState.String() == nodeNetworkState.Status.CurrentState.String() {
 		log.Info("Skipping NodeNetworkState update, node network configuration not changed")
 		return nil
 	}
 
+	nodeNetworkState.Status.HandlerNetworkManagerVersion = versions.HandlerNetworkManagerVersion
+	nodeNetworkState.Status.HandlerNmstateVersion = versions.HandlerNmstateVersion
+	nodeNetworkState.Status.HostNetworkManagerVersion = versions.HostNmstateVersion
+
 	nodeNetworkState.Status.CurrentState = observedState
 	nodeNetworkState.Status.LastSuccessfulUpdateTime = metav1.Time{Time: time.Now()}
 
@@ -85,6 +113,18 @@ func UpdateCurrentState(client client.Client, nodeNetworkState *nmstatev1beta1.N
 	return nil
 }
 
+func ExecuteCommand(command string, arguments ...string) (string, error) {
+	cmd := exec.Command(command, arguments...)
+	var stdout, stderr bytes.Buffer
+	cmd.Stdout = &stdout
+	cmd.Stderr = &stderr
+	if err := cmd.Run(); err != nil {
+		return "", fmt.Errorf("failed to execute %s: '%s', '%s', '%s'", command, err.Error(), stdout.String(), stderr.String())
+	}
+
+	return string(bytes.Trim(stdout.Bytes(), "\n")), nil
+}
+
 func rollback(client client.Client, probes []probe.Probe, cause error) error {
 	message := fmt.Sprintf("rolling back desired state configuration: %s", cause)
 	err := nmstatectl.Rollback()
@@ -95,7 +135,7 @@ func rollback(client client.Client, probes []probe.Probe, cause error) error {
 	// wait for system to settle after rollback
 	probesErr := probe.Run(client, probes)
 	if probesErr != nil {
-		return errors.Wrap(errors.Wrap(err, "failed running probes after rollback"), message)
+		return errors.Wrap(errors.Wrap(probesErr, "failed running probes after rollback"), message)
 	}
 	return errors.New(message)
 }
