@@ -1,9 +1,26 @@
+/*
+Copyright The Kubernetes NMState Authors.
+
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+*/
+
 package node
 
 import (
 	"context"
 
-	nmstatev1beta1 "github.com/nmstate/kubernetes-nmstate/api/v1beta1"
+	nmstatev1 "github.com/nmstate/kubernetes-nmstate/api/v1"
 	"github.com/nmstate/kubernetes-nmstate/pkg/enactment"
 	"k8s.io/apimachinery/pkg/util/intstr"
 
@@ -14,8 +31,8 @@ import (
 )
 
 const (
-	DEFAULT_MAXUNAVAILABLE = "50%"
-	MIN_MAXUNAVAILABLE     = 1
+	DefaultMaxunavailable = "50%"
+	MinMaxunavailable     = 1
 )
 
 type MaxUnavailableLimitReachedError struct{}
@@ -50,12 +67,12 @@ func NodesRunningNmstate(cli client.Reader, nodeSelector map[string]string) ([]c
 	return filteredNodes, nil
 }
 
-func MaxUnavailableNodeCount(cli client.Reader, policy *nmstatev1beta1.NodeNetworkConfigurationPolicy) (int, error) {
+func MaxUnavailableNodeCount(cli client.Reader, policy *nmstatev1.NodeNetworkConfigurationPolicy) (int, error) {
 	enactmentsTotal, _, err := enactment.CountByPolicy(cli, policy)
 	if err != nil {
-		return MIN_MAXUNAVAILABLE, err
+		return MinMaxunavailable, err
 	}
-	intOrPercent := intstr.FromString(DEFAULT_MAXUNAVAILABLE)
+	intOrPercent := intstr.FromString(DefaultMaxunavailable)
 	if policy.Spec.MaxUnavailable != nil {
 		intOrPercent = *policy.Spec.MaxUnavailable
 	}
@@ -65,13 +82,13 @@ func MaxUnavailableNodeCount(cli client.Reader, policy *nmstatev1beta1.NodeNetwo
 func ScaledMaxUnavailableNodeCount(matchingNodes int, intOrPercent intstr.IntOrString) (int, error) {
 	correctMaxUnavailable := func(maxUnavailable int) int {
 		if maxUnavailable < 1 {
-			return MIN_MAXUNAVAILABLE
+			return MinMaxunavailable
 		}
 		return maxUnavailable
 	}
 	maxUnavailable, err := intstr.GetScaledValueFromIntOrPercent(&intOrPercent, matchingNodes, true)
 	if err != nil {
-		defaultMaxUnavailable := intstr.FromString(DEFAULT_MAXUNAVAILABLE)
+		defaultMaxUnavailable := intstr.FromString(DefaultMaxunavailable)
 		maxUnavailable, _ = intstr.GetScaledValueFromIntOrPercent(
 			&defaultMaxUnavailable,
 			matchingNodes,
