@@ -1,3 +1,20 @@
+/*
+Copyright The Kubernetes NMState Authors.
+
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+*/
+
 package handler
 
 import (
@@ -35,17 +52,6 @@ func ethernetNicsUp(nics ...string) nmstate.State {
 	return ethernetNicsState(states)
 }
 
-func linuxBrBadYaml(name string) nmstate.State {
-	return nmstate.NewState(fmt.Sprintf(`interfaces:
-  - name: %s
-    type: linux-bridge
-    state: badstate
-    bridge:
-      port:
-        - name: eth1
-`, name))
-}
-
 func linuxBrUp(bridgeName string) nmstate.State {
 	return nmstate.NewState(fmt.Sprintf(`interfaces:
   - name: %s
@@ -161,7 +167,7 @@ func ovsbBrWithInternalInterface(bridgeName string) nmstate.State {
 		bridgeName, firstSecondaryNic))
 }
 
-func ifaceUpWithStaticIP(iface string, ipAddress string) nmstate.State {
+func ifaceUpWithStaticIP(iface string, ipAddress string, prefixLen string) nmstate.State {
 	return nmstate.NewState(fmt.Sprintf(`interfaces:
     - name: %s
       type: ethernet
@@ -169,13 +175,23 @@ func ifaceUpWithStaticIP(iface string, ipAddress string) nmstate.State {
       ipv4:
         address:
         - ip: %s
-          prefix-length: 24
+          prefix-length: %s
         dhcp: false
         enabled: true
-`, iface, ipAddress))
+`, iface, ipAddress, prefixLen))
 }
 
-func ifaceUpWithVlanUp(iface string, vlanId string) nmstate.State {
+func ifaceUpWithStaticIPAbsent(firstSecondaryNic string) nmstate.State {
+	return nmstate.NewState(fmt.Sprintf(`interfaces:
+  - name: %s
+    type: ethernet
+    state: up
+    ipv4:
+      enabled: false
+`, firstSecondaryNic))
+}
+
+func ifaceUpWithVlanUp(iface string, vlanID string) nmstate.State {
 	return nmstate.NewState(fmt.Sprintf(`interfaces:
     - name: %s.%s
       type: vlan
@@ -183,10 +199,10 @@ func ifaceUpWithVlanUp(iface string, vlanId string) nmstate.State {
       vlan:
         base-iface: %s
         id: %s
-`, iface, vlanId, iface, vlanId))
+`, iface, vlanID, iface, vlanID))
 }
 
-func vlanAbsent(iface string, vlanId string) nmstate.State {
+func vlanAbsent(iface string, vlanID string) nmstate.State {
 	return nmstate.NewState(fmt.Sprintf(`interfaces:
     - name: %s.%s
       type: vlan
@@ -194,7 +210,7 @@ func vlanAbsent(iface string, vlanId string) nmstate.State {
       vlan:
         base-iface: %s
         id: %s
-`, iface, vlanId, iface, vlanId))
+`, iface, vlanID, iface, vlanID))
 }
 
 func interfaceAbsent(iface string) nmstate.State {
@@ -251,6 +267,23 @@ func resetPrimaryAndSecondaryNICs() nmstate.State {
 `, primaryNic, firstSecondaryNic, secondSecondaryNic))
 }
 
+func bridgeOnTheSecondaryInterfaceState() nmstate.State {
+	return nmstate.NewState(`interfaces:
+  - name: brext
+    type: linux-bridge
+    state: up
+    ipv4: "{{ capture.secondary-iface.interfaces.0.ipv4 }}"
+    bridge:
+      options:
+        stp:
+          enabled: false
+      port:
+      - name: "{{ capture.secondary-iface.interfaces.0.name }}"
+routes:
+  config: "{{ capture.bridge-routes.routes.running }}"
+`)
+}
+
 func matchingBond(expectedBond map[string]interface{}) types.GomegaMatcher {
 	expectedLinkAggregation := expectedBond["link-aggregation"].(map[string]interface{})
 	expectedOptions := expectedLinkAggregation["options"].(map[string]interface{})
