@@ -1,3 +1,20 @@
+/*
+Copyright The Kubernetes NMState Authors.
+
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+*/
+
 package handler
 
 import (
@@ -15,12 +32,15 @@ import (
 
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/types"
+	"k8s.io/apimachinery/pkg/util/intstr"
 	yaml "sigs.k8s.io/yaml"
 
 	dynclient "sigs.k8s.io/controller-runtime/pkg/client"
 
 	nmstate "github.com/nmstate/kubernetes-nmstate/api/shared"
+	nmstatev1 "github.com/nmstate/kubernetes-nmstate/api/v1"
 	nmstatev1beta1 "github.com/nmstate/kubernetes-nmstate/api/v1beta1"
+	nmstatenode "github.com/nmstate/kubernetes-nmstate/pkg/node"
 	"github.com/nmstate/kubernetes-nmstate/test/cmd"
 	"github.com/nmstate/kubernetes-nmstate/test/e2e/handler/linuxbridge"
 	testenv "github.com/nmstate/kubernetes-nmstate/test/env"
@@ -33,16 +53,20 @@ const ReadInterval = 1 * time.Second
 const TestPolicy = "test-policy"
 
 var (
-	bridgeCounter   = 0
-	bondConunter    = 0
-	parallelRollout = environment.GetBoolVarWithDefault("NMSTATE_PARALLEL_ROLLOUT", false)
+	bridgeCounter  = 0
+	bondCounter    = 0
+	maxUnavailable = environment.GetVarWithDefault("NMSTATE_MAX_UNAVAILABLE", nmstatenode.DefaultMaxunavailable)
 )
 
+func Byf(message string, arguments ...interface{}) {
+	By(fmt.Sprintf(message, arguments...))
+}
+
 func interfacesName(interfaces []interface{}) []string {
 	var names []string
 	for _, iface := range interfaces {
 		name, hasName := iface.(map[string]interface{})["name"]
-		Expect(hasName).To(BeTrue(), "should have name field in the interfaces, https://github.com/nmstate/nmstate/blob/master/libnmstate/schemas/operational-state.yaml")
+		Expect(hasName).To(BeTrue(), "should have name field in the interfaces, https://github.com/nmstate/nmstate/blob/base/libnmstate/schemas/operational-state.yaml")
 		names = append(names, name.(string))
 	}
 	return names
@@ -52,7 +76,7 @@ func interfaceByName(interfaces []interface{}, searchedName string) map[string]i
 	var dummy map[string]interface{}
 	for _, iface := range interfaces {
 		name, hasName := iface.(map[string]interface{})["name"]
-		Expect(hasName).To(BeTrue(), "should have name field in the interfaces, https://github.com/nmstate/nmstate/blob/master/libnmstate/schemas/operational-state.yaml")
+		Expect(hasName).To(BeTrue(), "should have name field in the interfaces, https://github.com/nmstate/nmstate/blob/base/libnmstate/schemas/operational-state.yaml")
 		if name == searchedName {
 			return iface.(map[string]interface{})
 		}
@@ -61,22 +85,40 @@ func interfaceByName(interfaces []interface{}, searchedName string) map[string]i
 	return dummy
 }
 
-func setDesiredStateWithPolicyAndNodeSelector(name string, desiredState nmstate.State, nodeSelector map[string]string) {
-	policy := nmstatev1beta1.NodeNetworkConfigurationPolicy{}
+func setDesiredStateWithPolicyAndCaptureAndNodeSelector(name string, desiredState nmstate.State, capture map[string]string, nodeSelector map[string]string) error {
+	policy := nmstatev1.NodeNetworkConfigurationPolicy{}
 	policy.Name = name
 	key := types.NamespacedName{Name: name}
-	Eventually(func() error {
-		err := testenv.Client.Get(context.TODO(), key, &policy)
-		policy.Spec.DesiredState = desiredState
-		policy.Spec.NodeSelector = nodeSelector
-		policy.Spec.Parallel = parallelRollout
-		if err != nil {
-			if apierrors.IsNotFound(err) {
-				return testenv.Client.Create(context.TODO(), &policy)
-			}
-			return err
+	err := testenv.Client.Get(context.TODO(), key, &policy)
+	policy.Spec.DesiredState = desiredState
+	policy.Spec.Capture = capture
+	policy.Spec.NodeSelector = nodeSelector
+	maxUnavailableIntOrString := intstr.FromString(maxUnavailable)
+	policy.Spec.MaxUnavailable = &maxUnavailableIntOrString
+	if err != nil {
+		if apierrors.IsNotFound(err) {
+			return testenv.Client.Create(context.TODO(), &policy)
 		}
-		return testenv.Client.Update(context.TODO(), &policy)
+		return err
+	}
+	err = testenv.Client.Update(context.TODO(), &policy)
+	if err != nil {
+		fmt.Println("Update error: " + err.Error())
+	}
+	return err
+}
+
+func setDesiredStateWithPolicyAndNodeSelector(name string, desiredState nmstate.State, nodeSelector map[string]string) error {
+	return setDesiredStateWithPolicyAndCaptureAndNodeSelector(name, desiredState, nil, nodeSelector)
+}
+
+func setDesiredStateWithPolicyAndNodeSelectorEventually(name string, desiredState nmstate.State, nodeSelector map[string]string) {
+	setDesiredStateWithPolicyAndCaptureAndNodeSelectorEventually(name, desiredState, nil, nodeSelector)
+}
+
+func setDesiredStateWithPolicyAndCaptureAndNodeSelectorEventually(name string, desiredState nmstate.State, capture map[string]string, nodeSelector map[string]string) {
+	Eventually(func() error {
+		return setDesiredStateWithPolicyAndCaptureAndNodeSelector(name, desiredState, capture, nodeSelector)
 	}, ReadTimeout, ReadInterval).ShouldNot(HaveOccurred(), fmt.Sprintf("Failed updating desired state : %s", desiredState))
 	//FIXME: until we don't have webhook we have to wait for reconcile
 	//       to start so we are sure that conditions are reset and we can
@@ -85,12 +127,17 @@ func setDesiredStateWithPolicyAndNodeSelector(name string, desiredState nmstate.
 }
 
 func setDesiredStateWithPolicyWithoutNodeSelector(name string, desiredState nmstate.State) {
-	setDesiredStateWithPolicyAndNodeSelector(name, desiredState, map[string]string{})
+	setDesiredStateWithPolicyAndNodeSelectorEventually(name, desiredState, map[string]string{})
 }
 
 func setDesiredStateWithPolicy(name string, desiredState nmstate.State) {
 	runAtWorkers := map[string]string{"node-role.kubernetes.io/worker": ""}
-	setDesiredStateWithPolicyAndNodeSelector(name, desiredState, runAtWorkers)
+	setDesiredStateWithPolicyAndNodeSelectorEventually(name, desiredState, runAtWorkers)
+}
+
+func setDesiredStateWithPolicyAndCapture(name string, desiredState nmstate.State, capture map[string]string) {
+	runAtWorkers := map[string]string{"node-role.kubernetes.io/worker": ""}
+	setDesiredStateWithPolicyAndCaptureAndNodeSelectorEventually(name, desiredState, capture, runAtWorkers)
 }
 
 func updateDesiredState(desiredState nmstate.State) {
@@ -103,12 +150,20 @@ func updateDesiredStateAndWait(desiredState nmstate.State) {
 }
 
 func updateDesiredStateAtNode(node string, desiredState nmstate.State) {
+	updateDesiredStateWithCaptureAtNode(node, desiredState, nil)
+}
+
+func updateDesiredStateWithCaptureAtNode(node string, desiredState nmstate.State, capture map[string]string) {
 	nodeSelector := map[string]string{"kubernetes.io/hostname": node}
-	setDesiredStateWithPolicyAndNodeSelector(TestPolicy, desiredState, nodeSelector)
+	setDesiredStateWithPolicyAndCaptureAndNodeSelectorEventually(TestPolicy, desiredState, capture, nodeSelector)
 }
 
 func updateDesiredStateAtNodeAndWait(node string, desiredState nmstate.State) {
-	updateDesiredStateAtNode(node, desiredState)
+	updateDesiredStateWithCaptureAtNodeAndWait(node, desiredState, nil)
+}
+
+func updateDesiredStateWithCaptureAtNodeAndWait(node string, desiredState nmstate.State, capture map[string]string) {
+	updateDesiredStateWithCaptureAtNode(node, desiredState, capture)
 	waitForAvailableTestPolicy()
 }
 
@@ -129,9 +184,9 @@ func nodeNetworkState(key types.NamespacedName) nmstatev1beta1.NodeNetworkState
 	return state
 }
 
-func nodeNetworkConfigurationPolicy(policyName string) nmstatev1beta1.NodeNetworkConfigurationPolicy {
+func nodeNetworkConfigurationPolicy(policyName string) nmstatev1.NodeNetworkConfigurationPolicy {
 	key := types.NamespacedName{Name: policyName}
-	policy := nmstatev1beta1.NodeNetworkConfigurationPolicy{}
+	policy := nmstatev1.NodeNetworkConfigurationPolicy{}
 	EventuallyWithOffset(1, func() error {
 		return testenv.Client.Get(context.TODO(), key, &policy)
 	}, ReadTimeout, ReadInterval).ShouldNot(HaveOccurred())
@@ -150,8 +205,8 @@ func deleteNodeNeworkStates() {
 }
 
 func deletePolicy(name string) {
-	By(fmt.Sprintf("Deleting policy %s", name))
-	policy := &nmstatev1beta1.NodeNetworkConfigurationPolicy{}
+	Byf("Deleting policy %s", name)
+	policy := &nmstatev1.NodeNetworkConfigurationPolicy{}
 	policy.Name = name
 	err := testenv.Client.Delete(context.TODO(), policy)
 	if apierrors.IsNotFound(err) {
@@ -161,7 +216,7 @@ func deletePolicy(name string) {
 
 	// Wait for policy to be removed
 	EventuallyWithOffset(1, func() bool {
-		err := testenv.Client.Get(context.TODO(), types.NamespacedName{Name: name}, &nmstatev1beta1.NodeNetworkConfigurationPolicy{})
+		err := testenv.Client.Get(context.TODO(), types.NamespacedName{Name: name}, &nmstatev1.NodeNetworkConfigurationPolicy{})
 		return apierrors.IsNotFound(err)
 	}, 60*time.Second, 1*time.Second).Should(BeTrue(), fmt.Sprintf("Policy %s not deleted", name))
 
@@ -181,16 +236,23 @@ func deletePolicy(name string) {
 			return apierrors.IsNotFound(err)
 		}, enactmentsDeleteTimeout, 1*time.Second).Should(BeTrue(), fmt.Sprintf("Enactment %s not deleted", enactmentKey.Name))
 	}
-
 }
 
 func restartNode(node string) error {
-	By(fmt.Sprintf("Restarting node %s", node))
+	restartNodeWithoutWaiting(node)
+	return waitFotNodeToStart(node)
+}
+
+func restartNodeWithoutWaiting(node string) {
+	Byf("Restarting node %s", node)
 	// Use halt so reboot command does not get stuck also
 	// this command always fail since connection is closed
 	// so let's not check err
 	runner.RunAtNode(node, "sudo", "halt", "--reboot")
-	By(fmt.Sprintf("Waiting till node %s is rebooted", node))
+}
+
+func waitFotNodeToStart(node string) error {
+	Byf("Waiting till node %s is rebooted", node)
 	// It will wait till uptime -p will return up that means that node was currently rebooted and is 0 min up
 	Eventually(func() string {
 		output, err := runner.RunAtNode(node, "uptime", "-p")
@@ -199,38 +261,49 @@ func restartNode(node string) error {
 		}
 		return output
 	}, 300*time.Second, 5*time.Second).ShouldNot(Equal("up"), fmt.Sprintf("Node %s failed to start after reboot", node))
-
 	return nil
 }
 
-func deleteBridgeAtNodes(bridgeName string, ports ...string) []error {
-	By(fmt.Sprintf("Delete bridge %s", bridgeName))
-	_, errs := runner.RunAtNodes(nodes, "sudo", "ip", "link", "del", bridgeName)
-	for _, portName := range ports {
-		_, slaveErrors := runner.RunAtNodes(nodes, "sudo", "nmcli", "con", "delete", bridgeName+"-"+portName)
-		errs = append(errs, slaveErrors...)
-	}
-	return errs
-}
-
-func createDummyAtNodes(dummyName string) []error {
-	By(fmt.Sprintf("Creating dummy %s", dummyName))
-	_, errs := runner.RunAtNodes(nodes, "sudo", "nmcli", "con", "add", "type", "dummy", "con-name", dummyName, "ifname", dummyName, "ip4", "192.169.1.50/24")
-	_, upErrs := runner.RunAtNodes(nodes, "sudo", "nmcli", "con", "up", dummyName)
+func createDummyConnection(nodesToModify []string, dummyName string) []error {
+	Byf("Creating dummy %s", dummyName)
+	_, errs := runner.RunAtNodes(nodesToModify, "sudo", "nmcli", "con", "add", "type", "dummy", "con-name", dummyName, "ifname", dummyName, "ip4", "192.169.1.50/24")
+	_, upErrs := runner.RunAtNodes(nodesToModify, "sudo", "nmcli", "con", "up", dummyName)
 	errs = append(errs, upErrs...)
 	return errs
 }
 
-func deleteConnectionAtNodes(name string) []error {
-	By(fmt.Sprintf("Delete connection %s", name))
-	_, errs := runner.RunAtNodes(nodes, "sudo", "nmcli", "con", "delete", name)
+func createDummyConnectionAtNodes(dummyName string) []error {
+	return createDummyConnection(nodes, dummyName)
+}
+
+func createDummyConnectionAtAllNodes(dummyName string) []error {
+	return createDummyConnection(allNodes, dummyName)
+}
+
+func deleteConnection(nodesToModify []string, name string) []error {
+	Byf("Delete connection %s", name)
+	_, errs := runner.RunAtNodes(nodesToModify, "sudo", "nmcli", "con", "delete", name)
 	return errs
 }
 
-func deleteDeviceAtNode(node string, name string) error {
-	By(fmt.Sprintf("Delete device %s  at node %s", name, node))
-	_, err := runner.RunAtNode(node, "sudo", "nmcli", "device", "delete", name)
-	return err
+func deleteDevice(nodesToModify []string, name string) []error {
+	Byf("Delete device %s  at nodes %v", name, nodesToModify)
+	_, errs := runner.RunAtNodes(nodesToModify, "sudo", "nmcli", "device", "delete", name)
+	return errs
+}
+
+func waitForInterfaceDeletion(nodesToCheck []string, interfaceName string) {
+	for _, nodeName := range nodesToCheck {
+		Eventually(func() []string {
+			return interfacesNameForNode(nodeName)
+		}, 2*nmstatenode.NetworkStateRefresh, time.Second).ShouldNot(ContainElement(interfaceName))
+	}
+}
+
+func deleteConnectionAndWait(nodesToModify []string, interfaceName string) {
+	deleteConnection(nodesToModify, interfaceName)
+	deleteDevice(nodesToModify, interfaceName)
+	waitForInterfaceDeletion(nodesToModify, interfaceName)
 }
 
 func interfaces(state nmstate.State) []interface{} {
@@ -271,18 +344,24 @@ func ipAddressForNodeInterfaceEventually(node string, iface string) AsyncAsserti
 	}, ReadTimeout, ReadInterval)
 }
 
+func ipV6AddressForNodeInterfaceEventually(node string, iface string) AsyncAssertion {
+	return Eventually(func() string {
+		return ipv6Address(node, iface)
+	}, ReadTimeout, ReadInterval)
+}
+
+func routeDestForNodeInterfaceEventually(node string, destIP string) AsyncAssertion {
+	return Eventually(func() string {
+		return routeDest(node, destIP)
+	}, ReadTimeout, ReadInterval)
+}
+
 func vlanForNodeInterfaceEventually(node string, iface string) AsyncAssertion {
 	return Eventually(func() string {
 		return vlan(node, iface)
 	}, ReadTimeout, ReadInterval)
 }
 
-func interfacesNameForNodeConsistently(node string) AsyncAssertion {
-	return Consistently(func() []string {
-		return interfacesNameForNode(node)
-	}, 5*time.Second, 1*time.Second)
-}
-
 func interfacesForNode(node string) AsyncAssertion {
 	return Eventually(func() []interface{} {
 		var currentStateYaml nmstate.State
@@ -295,29 +374,12 @@ func interfacesForNode(node string) AsyncAssertion {
 	}, ReadTimeout, ReadInterval)
 }
 
-func waitForNodeNetworkStateUpdate(node string) {
-	now := time.Now()
-	EventuallyWithOffset(1, func() time.Time {
-		key := types.NamespacedName{Name: node}
-		nnsUpdateTime := nodeNetworkState(key).Status.LastSuccessfulUpdateTime
-		return nnsUpdateTime.Time
-	}, 4*time.Minute, 5*time.Second).Should(BeTemporally(">=", now), fmt.Sprintf("Node %s should have a fresh nns)", node))
-
-}
-
-func toUnstructured(y string) interface{} {
-	var u interface{}
-	err := yaml.Unmarshal([]byte(y), &u)
-	Expect(err).ToNot(HaveOccurred())
-	return u
-}
-
 func bridgeVlansAtNode(node string) (string, error) {
 	return runner.RunAtNode(node, "sudo", "bridge", "-j", "vlan", "show")
 }
 
 func getVLANFlagsEventually(node string, connection string, vlan int) AsyncAssertion {
-	By(fmt.Sprintf("Getting vlan filtering flags for node %s connection %s and vlan %d", node, connection, vlan))
+	Byf("Getting vlan filtering flags for node %s connection %s and vlan %d", node, connection, vlan)
 	return Eventually(func() []string {
 		bridgeVlans, err := bridgeVlansAtNode(node)
 		if err != nil {
@@ -331,7 +393,7 @@ func getVLANFlagsEventually(node string, connection string, vlan int) AsyncAsser
 			// [1] https://bugs.centos.org/view.php?id=16533
 			output, err := cmd.Run("test/e2e/get-bridge-vlans-flags-el8.sh", false, node, connection, strconv.Itoa(vlan))
 			Expect(err).ToNot(HaveOccurred())
-			return strings.Split(string(output), " ")
+			return strings.Split(output, " ")
 		} else {
 			By("Getting vlan filtering from json output")
 			parsedBridgeVlans := gjson.Parse(bridgeVlans)
@@ -354,12 +416,11 @@ func getVLANFlagsEventually(node string, connection string, vlan int) AsyncAsser
 }
 
 func hasVlans(node string, connection string, minVlan int, maxVlan int) AsyncAssertion {
-
 	ExpectWithOffset(1, minVlan).To(BeNumerically(">", 0))
 	ExpectWithOffset(1, maxVlan).To(BeNumerically(">", 0))
 	ExpectWithOffset(1, maxVlan).To(BeNumerically(">=", minVlan))
 
-	By(fmt.Sprintf("Check %s has %s with vlan filtering vids %d-%d", node, connection, minVlan, maxVlan))
+	Byf("Check %s has %s with vlan filtering vids %d-%d", node, connection, minVlan, maxVlan)
 	return Eventually(func() error {
 		bridgeVlans, err := bridgeVlansAtNode(node)
 		if err != nil {
@@ -377,8 +438,8 @@ func hasVlans(node string, connection string, minVlan int, maxVlan int) AsyncAss
 			parsedBridgeVlans := gjson.Parse(bridgeVlans)
 			gjsonExpression := linuxbridge.BuildGJsonExpression(bridgeVlans)
 			for expectedVlan := minVlan; expectedVlan <= maxVlan; expectedVlan++ {
-				vlanByIdAndConection := fmt.Sprintf(gjsonExpression, connection, expectedVlan)
-				if !parsedBridgeVlans.Get(vlanByIdAndConection).Exists() {
+				vlanByIDAndConection := fmt.Sprintf(gjsonExpression, connection, expectedVlan)
+				if !parsedBridgeVlans.Get(vlanByIDAndConection).Exists() {
 					return fmt.Errorf("bridge connection %s has no vlan %d, obtainedVlans: \n %s", connection, expectedVlan, bridgeVlans)
 				}
 			}
@@ -388,7 +449,7 @@ func hasVlans(node string, connection string, minVlan int, maxVlan int) AsyncAss
 }
 
 func vlansCardinality(node string, connection string) AsyncAssertion {
-	By(fmt.Sprintf("Getting vlan cardinality for node %s connection %s", node, connection))
+	Byf("Getting vlan cardinality for node %s connection %s", node, connection)
 	return Eventually(func() (int, error) {
 		bridgeVlans, err := bridgeVlansAtNode(node)
 		if err != nil {
@@ -397,7 +458,6 @@ func vlansCardinality(node string, connection string) AsyncAssertion {
 
 		return len(gjson.Parse(bridgeVlans).Get(connection).Array()), nil
 	}, ReadTimeout, ReadInterval)
-
 }
 
 func bridgeDescription(node string, bridgeName string) AsyncAssertion {
@@ -412,16 +472,16 @@ func nextBridge() string {
 }
 
 func nextBond() string {
-	bridgeCounter++
-	return fmt.Sprintf("bond%d", bondConunter)
+	bondCounter++
+	return fmt.Sprintf("bond%d", bondCounter)
 }
 
 func currentStateJSON(node string) []byte {
 	key := types.NamespacedName{Name: node}
 	currentState := nodeNetworkState(key).Status.CurrentState
-	currentStateJson, err := yaml.YAMLToJSON(currentState.Raw)
+	currentStateJSON, err := yaml.YAMLToJSON(currentState.Raw)
 	ExpectWithOffset(1, err).ToNot(HaveOccurred())
-	return currentStateJson
+	return currentStateJSON
 }
 
 func dhcpFlag(node string, name string) bool {
@@ -454,7 +514,7 @@ func nodeInterfacesState(node string, exclude []string) []byte {
 	ifacesState := make(map[string]string)
 	for _, iface := range interfaces {
 		name, hasName := iface.(map[string]interface{})["name"]
-		Expect(hasName).To(BeTrue(), "should have name field in the interfaces, https://github.com/nmstate/nmstate/blob/master/libnmstate/schemas/operational-state.yaml")
+		Expect(hasName).To(BeTrue(), "should have name field in the interfaces, https://github.com/nmstate/nmstate/blob/base/libnmstate/schemas/operational-state.yaml")
 		if ifaceInSlice(name.(string), exclude) {
 			continue
 		}
@@ -476,6 +536,16 @@ func ipv4Address(node string, iface string) string {
 	return gjson.ParseBytes(currentStateJSON(node)).Get(path).String()
 }
 
+func ipv6Address(node string, iface string) string {
+	path := fmt.Sprintf("interfaces.#(name==\"%s\").ipv6.address.0.ip", iface)
+	return gjson.ParseBytes(currentStateJSON(node)).Get(path).String()
+}
+
+func macAddress(node string, iface string) string {
+	path := fmt.Sprintf("interfaces.#(name==\"%s\").mac-address", iface)
+	return gjson.ParseBytes(currentStateJSON(node)).Get(path).String()
+}
+
 func defaultRouteNextHopInterface(node string) AsyncAssertion {
 	return Eventually(func() string {
 		path := "routes.running.#(destination==\"0.0.0.0/0\").next-hop-interface"
@@ -483,6 +553,18 @@ func defaultRouteNextHopInterface(node string) AsyncAssertion {
 	}, 15*time.Second, 1*time.Second)
 }
 
+func routeDest(node string, destIP string) string {
+	path := fmt.Sprintf("routes.running.#(destination==\"%s\")", destIP)
+	return gjson.ParseBytes(currentStateJSON(node)).Get(path).String()
+}
+
+func routeNextHopInterface(node string, destIP string) AsyncAssertion {
+	return Eventually(func() string {
+		path := fmt.Sprintf("routes.running.#(destination==\"%s\").next-hop-interface", destIP)
+		return gjson.ParseBytes(currentStateJSON(node)).Get(path).String()
+	}, 15*time.Second, 1*time.Second)
+}
+
 func vlan(node string, iface string) string {
 	vlanFilter := fmt.Sprintf("interfaces.#(name==\"%s\").vlan.id", iface)
 	return gjson.ParseBytes(currentStateJSON(node)).Get(vlanFilter).String()
@@ -499,3 +581,30 @@ func skipIfNotKubernetes() {
 		Skip("Tutorials use interface naming that is available only on Kubernetes providers")
 	}
 }
+
+func maxUnavailableNodes() int {
+	m, _ := nmstatenode.ScaledMaxUnavailableNodeCount(len(nodes), intstr.FromString(nmstatenode.DefaultMaxunavailable))
+	return m
+}
+
+func dnsResolverServerForNodeEventually(node string) AsyncAssertion {
+	return Eventually(func() []string {
+		return dnsResolverForNode(node, "dns-resolver.running.server")
+	}, ReadTimeout, ReadInterval)
+}
+
+func dnsResolverSearchForNodeEventually(node string) AsyncAssertion {
+	return Eventually(func() []string {
+		return dnsResolverForNode(node, "dns-resolver.running.search")
+	}, ReadTimeout, ReadInterval)
+}
+
+func dnsResolverForNode(node string, path string) []string {
+	var arr []string
+
+	elemList := gjson.ParseBytes(currentStateJSON(node)).Get(path).Array()
+	for _, elem := range elemList {
+		arr = append(arr, elem.String())
+	}
+	return arr
+}
